@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Source::DefaultGitHub;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2015-04-02'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -9,6 +9,12 @@ use Moose;
 with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::Section';
 
+has text => (
+    is => 'rw',
+    isa => 'Str',
+    default => 'Source repository is at L<%s>.',
+);
+
 sub weave_section {
     my ($self, $document, $input) = @_;
 
@@ -26,7 +32,7 @@ sub weave_section {
             or die "Can't parse github address in $file";
         $repo_url = "https://github.com/$1/$2";
     }
-    my $text = "Source repository is at L<$repo_url>.";
+    my $text = "Source repository is at L<$repo_url>.\n\n";
 
     #$text = Text::Wrap::wrap(q{}, q{}, $text);
     $self->add_text_to_section($document, $text, 'SOURCE');
@@ -48,7 +54,7 @@ Pod::Weaver::Section::Source::DefaultGitHub - Add a SOURCE section (repository d
 
 =head1 VERSION
 
-This document describes version 0.06 of Pod::Weaver::Section::Source::DefaultGitHub (from Perl distribution Pod-Weaver-Section-Source-DefaultGitHub), released on 2015-04-01.
+This document describes version 0.07 of Pod::Weaver::Section::Source::DefaultGitHub (from Perl distribution Pod-Weaver-Section-Source-DefaultGitHub), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -72,13 +78,23 @@ not specified) GitHub.
 
 =for Pod::Coverage weave_section
 
+=head1 ATTRIBUTES
+
+=head2 text
+
+The text that is added. C<%s> is replaced by the repository url.
+
+Default: C<Source repository is at LE<lt>%sE<gt>.>
+
 =head1 SEE ALSO
 
 L<Pod::Weaver::Section::SourceGitHub>
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Section-Source-DefaultGitHub>.=head1 SOURCE
+Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Section-Source-DefaultGitHub>.
+
+=head1 SOURCE
 
 Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Section-Source-DefaultGitHub>.
 
